# Contributing to GatherUp

The plan is to open this up to contributions in the form of Pull Requests, although initially I need to do a bunch of clean up tasks so it's best to raise an issue before making any effort writing code.

